@@ -1,14 +1,9 @@
 from sqlalchemy import Column, String, Integer, Float
 from sqlalchemy.ext.declarative import declarative_base
-from sqlalchemy.engine import create_engine
-from sqlalchemy.orm.session import Session
-import time
+from tools import get_session, get_engine
 import json
 
 Base = declarative_base()
-# generate tables
-# engine = create_engine("mysql+pymysql://root:Wangchenyu2012@127.0.0.1:3306/p3")
-# Base.metadata.create_all(engine)
 
 
 def database_toast(issue: int, name_cn: str, name: str, key: str, value: str):
@@ -17,31 +12,18 @@ def database_toast(issue: int, name_cn: str, name: str, key: str, value: str):
 
 
 def get_session_sport():
-    # path_db = r'C:\Users\Wangjulong\tensorflows\p3.db'
-    # path_str = 'sqlite:///' + path_db
-    # db_engine = create_engine(path_str, echo=False)
-    # session = Session(db_engine)
-    # return session
-    # mysql+pymysql://<username>:<password>@<host>/<dbname>[?<options>]
-    engine = create_engine("mysql+pymysql://root:Wangchenyu2012@127.0.0.1:3306/p3")
-    session = Session(engine)
+    session = get_session()
     return session
 
 
 def get_engine_sport():
-    # path_db = r'C:\Users\Wangjulong\tensorflows\p3.db'
-    # path_str = 'sqlite:///' + path_db
-    # db_engine = create_engine(path_str, echo=False)
-    # session = Session(db_engine)
-    # return session
-    # mysql+pymysql://<username>:<password>@<host>/<dbname>[?<options>]
-    engine = create_engine("mysql+pymysql://root:Wangchenyu2012@127.0.0.1:3306/p3")
+    engine = get_engine()
     return engine
 
 
 class SportNumber(Base):
     """ numbers@p3.db """
-    __tablename__ = 'numbers'
+    __tablename__ = 'number_p3'
 
     issue = Column(Integer, primary_key=True)
     num1 = Column(Integer, nullable=False)
@@ -135,1006 +117,6 @@ class SportNumber(Base):
         print(f">>> merge kill in kills:{p_issue} - {p_numbers}")
 
 
-class SportConfig(Base):
-    __tablename__ = 'configs'
-
-    name = Column(String(50), primary_key=True)
-    value = Column(String(50))
-
-    def __init__(self, name, value):
-        self.name = name
-        self.value = value
-
-    @classmethod
-    def get_all(cls):
-        """
-        获取所有的数据
-        """
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = {x.name: x.value for x in data}
-        return result
-
-    @classmethod
-    def get_item(cls, the_key: str):
-        """get value"""
-        session = get_session_sport()
-        data = session.query(cls).get(the_key)
-        session.close()
-        return data.value
-
-    @classmethod
-    def set_item(cls, the_key: str, the_value: str):
-        """set value"""
-        session = get_session_sport()
-        data = session.query(cls).get(the_key)
-        data.value = the_value
-        session.merge(data)
-        session.commit()
-        session.close()
-
-    @classmethod
-    def add_item(cls, the_key: str, the_value: str):
-        """add item"""
-        session = get_session_sport()
-        ins = cls(the_key, the_value)
-        session.merge(ins)
-        session.commit()
-        session.close()
-        print(f">>> add item success, name: {the_key}, value: {the_value}")
-
-
-class SportFollow1(Base):
-    __tablename__ = 'follow1'
-    issue = Column(Integer, primary_key=True)
-    num1 = Column(Integer, nullable=False)
-    num2 = Column(Integer, nullable=False)
-    num3 = Column(Integer, nullable=False)
-    next1 = Column(Integer)
-    next2 = Column(Integer)
-    next3 = Column(Integer)
-    f00 = Column(Integer)
-    f01 = Column(Integer)
-    f02 = Column(Integer)
-    f03 = Column(Integer)
-    f04 = Column(Integer)
-    f05 = Column(Integer)
-    f06 = Column(Integer)
-    f07 = Column(Integer)
-    f08 = Column(Integer)
-    f09 = Column(Integer)
-    f10 = Column(Integer)
-    f11 = Column(Integer)
-    f12 = Column(Integer)
-    f13 = Column(Integer)
-    f14 = Column(Integer)
-    f15 = Column(Integer)
-    f16 = Column(Integer)
-    f17 = Column(Integer)
-    f18 = Column(Integer)
-    f19 = Column(Integer)
-    f20 = Column(Integer)
-    f21 = Column(Integer)
-    f22 = Column(Integer)
-    f23 = Column(Integer)
-    f24 = Column(Integer)
-    f25 = Column(Integer)
-    f26 = Column(Integer)
-    f27 = Column(Integer)
-    f28 = Column(Integer)
-    f29 = Column(Integer)
-    f30 = Column(Integer)
-    f31 = Column(Integer)
-    f32 = Column(Integer)
-    f33 = Column(Integer)
-    f34 = Column(Integer)
-    f35 = Column(Integer)
-    f36 = Column(Integer)
-    f37 = Column(Integer)
-    f38 = Column(Integer)
-    f39 = Column(Integer)
-    f40 = Column(Integer)
-    f41 = Column(Integer)
-    f42 = Column(Integer)
-    f43 = Column(Integer)
-    f44 = Column(Integer)
-    f45 = Column(Integer)
-    f46 = Column(Integer)
-    f47 = Column(Integer)
-    f48 = Column(Integer)
-    f49 = Column(Integer)
-    f50 = Column(Integer)
-    f51 = Column(Integer)
-    f52 = Column(Integer)
-    f53 = Column(Integer)
-    f54 = Column(Integer)
-    f55 = Column(Integer)
-    f56 = Column(Integer)
-    f57 = Column(Integer)
-    f58 = Column(Integer)
-    f59 = Column(Integer)
-    f60 = Column(Integer)
-    f61 = Column(Integer)
-    f62 = Column(Integer)
-    f63 = Column(Integer)
-    f64 = Column(Integer)
-    f65 = Column(Integer)
-    f66 = Column(Integer)
-    f67 = Column(Integer)
-    f68 = Column(Integer)
-    f69 = Column(Integer)
-    f70 = Column(Integer)
-    f71 = Column(Integer)
-    f72 = Column(Integer)
-    f73 = Column(Integer)
-    f74 = Column(Integer)
-    f75 = Column(Integer)
-    f76 = Column(Integer)
-    f77 = Column(Integer)
-    f78 = Column(Integer)
-    f79 = Column(Integer)
-    f80 = Column(Integer)
-    f81 = Column(Integer)
-    f82 = Column(Integer)
-    f83 = Column(Integer)
-    f84 = Column(Integer)
-    f85 = Column(Integer)
-    f86 = Column(Integer)
-    f87 = Column(Integer)
-    f88 = Column(Integer)
-    f89 = Column(Integer)
-    f90 = Column(Integer)
-    f91 = Column(Integer)
-    f92 = Column(Integer)
-    f93 = Column(Integer)
-    f94 = Column(Integer)
-    f95 = Column(Integer)
-    f96 = Column(Integer)
-    f97 = Column(Integer)
-    f98 = Column(Integer)
-    f99 = Column(Integer)
-
-    def __init__(self, issue, n1, n2, n3) -> None:
-        super().__init__()
-        self.issue = issue
-        self.num1 = n1
-        self.num2 = n2
-        self.num3 = n3
-
-    @classmethod
-    def get_follow_4049(cls):
-        session = get_session_sport()
-        data = session.query(cls).all()
-        result = {}
-        for t in data:
-            result[t.issue] = [t.f40, t.f41, t.f42, t.f43, t.f44, t.f45, t.f46, t.f47, t.f48, t.f49]
-        return result
-
-    @classmethod
-    def get_numbers(cls):
-        """
-        [[issue, num1, num2, num3],...]
-        """
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = [[x.issue, x.num1, x.num2, x.num3] for x in data]
-        return result
-
-    @classmethod
-    def get_number_and_next(cls):
-        """
-        [[issue, num1, num2, num3, next1, next2, next3],...]
-        """
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = [[x.issue, x.num1, x.num2, x.num3, x.next1, x.next2, x.next3] for x in data]
-        return result
-
-    @classmethod
-    def get_all(cls):
-        """
-        获取所有的数据
-        """
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = [[
-            x.issue,
-            x.num1,
-            x.num2,
-            x.num3,
-            x.next1,
-            x.next2,
-            x.next3,
-            x.f00,
-            x.f01,
-            x.f02,
-            x.f03,
-            x.f04,
-            x.f05,
-            x.f06,
-            x.f07,
-            x.f08,
-            x.f09,
-            x.f10,
-            x.f11,
-            x.f12,
-            x.f13,
-            x.f14,
-            x.f15,
-            x.f16,
-            x.f17,
-            x.f18,
-            x.f19,
-            x.f20,
-            x.f21,
-            x.f22,
-            x.f23,
-            x.f24,
-            x.f25,
-            x.f26,
-            x.f27,
-            x.f28,
-            x.f29,
-            x.f30,
-            x.f31,
-            x.f32,
-            x.f33,
-            x.f34,
-            x.f35,
-            x.f36,
-            x.f37,
-            x.f38,
-            x.f39,
-            x.f40,
-            x.f41,
-            x.f42,
-            x.f43,
-            x.f44,
-            x.f45,
-            x.f46,
-            x.f47,
-            x.f48,
-            x.f49,
-            x.f50,
-            x.f51,
-            x.f52,
-            x.f53,
-            x.f54,
-            x.f55,
-            x.f56,
-            x.f57,
-            x.f58,
-            x.f59,
-            x.f60,
-            x.f61,
-            x.f62,
-            x.f63,
-            x.f64,
-            x.f65,
-            x.f66,
-            x.f67,
-            x.f68,
-            x.f69,
-            x.f70,
-            x.f71,
-            x.f72,
-            x.f73,
-            x.f74,
-            x.f75,
-            x.f76,
-            x.f77,
-            x.f78,
-            x.f79,
-            x.f80,
-            x.f81,
-            x.f82,
-            x.f83,
-            x.f84,
-            x.f85,
-            x.f86,
-            x.f87,
-            x.f88,
-            x.f89,
-            x.f90,
-            x.f91,
-            x.f92,
-            x.f93,
-            x.f94,
-            x.f95,
-            x.f96,
-            x.f97,
-            x.f98,
-            x.f99
-        ] for x in data]
-        return result
-
-    @classmethod
-    def get_issues(cls):
-        """get issues"""
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = [x.issue for x in data]
-        result.sort()
-        return result
-
-
-class SportFollow2(Base):
-    __tablename__ = 'follow2'
-    issue = Column(Integer, primary_key=True)
-    num1 = Column(Integer, nullable=False)
-    num2 = Column(Integer, nullable=False)
-    num3 = Column(Integer, nullable=False)
-    next1 = Column(Integer)
-    next2 = Column(Integer)
-    next3 = Column(Integer)
-    f00 = Column(Integer)
-    f01 = Column(Integer)
-    f02 = Column(Integer)
-    f03 = Column(Integer)
-    f04 = Column(Integer)
-    f05 = Column(Integer)
-    f06 = Column(Integer)
-    f07 = Column(Integer)
-    f08 = Column(Integer)
-    f09 = Column(Integer)
-    f10 = Column(Integer)
-    f11 = Column(Integer)
-    f12 = Column(Integer)
-    f13 = Column(Integer)
-    f14 = Column(Integer)
-    f15 = Column(Integer)
-    f16 = Column(Integer)
-    f17 = Column(Integer)
-    f18 = Column(Integer)
-    f19 = Column(Integer)
-    f20 = Column(Integer)
-    f21 = Column(Integer)
-    f22 = Column(Integer)
-    f23 = Column(Integer)
-    f24 = Column(Integer)
-    f25 = Column(Integer)
-    f26 = Column(Integer)
-    f27 = Column(Integer)
-    f28 = Column(Integer)
-    f29 = Column(Integer)
-    f30 = Column(Integer)
-    f31 = Column(Integer)
-    f32 = Column(Integer)
-    f33 = Column(Integer)
-    f34 = Column(Integer)
-    f35 = Column(Integer)
-    f36 = Column(Integer)
-    f37 = Column(Integer)
-    f38 = Column(Integer)
-    f39 = Column(Integer)
-    f40 = Column(Integer)
-    f41 = Column(Integer)
-    f42 = Column(Integer)
-    f43 = Column(Integer)
-    f44 = Column(Integer)
-    f45 = Column(Integer)
-    f46 = Column(Integer)
-    f47 = Column(Integer)
-    f48 = Column(Integer)
-    f49 = Column(Integer)
-    f50 = Column(Integer)
-    f51 = Column(Integer)
-    f52 = Column(Integer)
-    f53 = Column(Integer)
-    f54 = Column(Integer)
-    f55 = Column(Integer)
-    f56 = Column(Integer)
-    f57 = Column(Integer)
-    f58 = Column(Integer)
-    f59 = Column(Integer)
-    f60 = Column(Integer)
-    f61 = Column(Integer)
-    f62 = Column(Integer)
-    f63 = Column(Integer)
-    f64 = Column(Integer)
-    f65 = Column(Integer)
-    f66 = Column(Integer)
-    f67 = Column(Integer)
-    f68 = Column(Integer)
-    f69 = Column(Integer)
-    f70 = Column(Integer)
-    f71 = Column(Integer)
-    f72 = Column(Integer)
-    f73 = Column(Integer)
-    f74 = Column(Integer)
-    f75 = Column(Integer)
-    f76 = Column(Integer)
-    f77 = Column(Integer)
-    f78 = Column(Integer)
-    f79 = Column(Integer)
-    f80 = Column(Integer)
-    f81 = Column(Integer)
-    f82 = Column(Integer)
-    f83 = Column(Integer)
-    f84 = Column(Integer)
-    f85 = Column(Integer)
-    f86 = Column(Integer)
-    f87 = Column(Integer)
-    f88 = Column(Integer)
-    f89 = Column(Integer)
-    f90 = Column(Integer)
-    f91 = Column(Integer)
-    f92 = Column(Integer)
-    f93 = Column(Integer)
-    f94 = Column(Integer)
-    f95 = Column(Integer)
-    f96 = Column(Integer)
-    f97 = Column(Integer)
-    f98 = Column(Integer)
-    f99 = Column(Integer)
-
-    def __init__(self, issue, n1, n2, n3) -> None:
-        super().__init__()
-        self.issue = issue
-        self.num1 = n1
-        self.num2 = n2
-        self.num3 = n3
-
-    @classmethod
-    def get_follow_4049(cls):
-        session = get_session_sport()
-        data = session.query(cls).all()
-        result = {}
-        for t in data:
-            result[t.issue] = [t.f40, t.f41, t.f42, t.f43, t.f44, t.f45, t.f46, t.f47, t.f48, t.f49]
-        return result
-
-    @classmethod
-    def get_numbers(cls):
-        """
-        [[issue, num1, num2, num3],...]
-        """
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = [[x.issue, x.num1, x.num2, x.num3] for x in data]
-        return result
-
-    @classmethod
-    def get_number_and_next(cls):
-        """
-        [[issue, num1, num2, num3, next1, next2, next3],...]
-        """
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = [[x.issue, x.num1, x.num2, x.num3, x.next1, x.next2, x.next3] for x in data]
-        return result
-
-    @classmethod
-    def get_all(cls):
-        """
-        获取所有的数据
-        """
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = [[
-            x.issue,
-            x.num1,
-            x.num2,
-            x.num3,
-            x.next1,
-            x.next2,
-            x.next3,
-            x.f00,
-            x.f01,
-            x.f02,
-            x.f03,
-            x.f04,
-            x.f05,
-            x.f06,
-            x.f07,
-            x.f08,
-            x.f09,
-            x.f10,
-            x.f11,
-            x.f12,
-            x.f13,
-            x.f14,
-            x.f15,
-            x.f16,
-            x.f17,
-            x.f18,
-            x.f19,
-            x.f20,
-            x.f21,
-            x.f22,
-            x.f23,
-            x.f24,
-            x.f25,
-            x.f26,
-            x.f27,
-            x.f28,
-            x.f29,
-            x.f30,
-            x.f31,
-            x.f32,
-            x.f33,
-            x.f34,
-            x.f35,
-            x.f36,
-            x.f37,
-            x.f38,
-            x.f39,
-            x.f40,
-            x.f41,
-            x.f42,
-            x.f43,
-            x.f44,
-            x.f45,
-            x.f46,
-            x.f47,
-            x.f48,
-            x.f49,
-            x.f50,
-            x.f51,
-            x.f52,
-            x.f53,
-            x.f54,
-            x.f55,
-            x.f56,
-            x.f57,
-            x.f58,
-            x.f59,
-            x.f60,
-            x.f61,
-            x.f62,
-            x.f63,
-            x.f64,
-            x.f65,
-            x.f66,
-            x.f67,
-            x.f68,
-            x.f69,
-            x.f70,
-            x.f71,
-            x.f72,
-            x.f73,
-            x.f74,
-            x.f75,
-            x.f76,
-            x.f77,
-            x.f78,
-            x.f79,
-            x.f80,
-            x.f81,
-            x.f82,
-            x.f83,
-            x.f84,
-            x.f85,
-            x.f86,
-            x.f87,
-            x.f88,
-            x.f89,
-            x.f90,
-            x.f91,
-            x.f92,
-            x.f93,
-            x.f94,
-            x.f95,
-            x.f96,
-            x.f97,
-            x.f98,
-            x.f99
-        ] for x in data]
-        return result
-
-    @classmethod
-    def get_issues(cls):
-        """get issues"""
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = [x.issue for x in data]
-        result.sort()
-        return result
-
-
-class SportFollow3(Base):
-    __tablename__ = 'follow3'
-    issue = Column(Integer, primary_key=True)
-    num1 = Column(Integer, nullable=False)
-    num2 = Column(Integer, nullable=False)
-    num3 = Column(Integer, nullable=False)
-    next1 = Column(Integer)
-    next2 = Column(Integer)
-    next3 = Column(Integer)
-    f00 = Column(Integer)
-    f01 = Column(Integer)
-    f02 = Column(Integer)
-    f03 = Column(Integer)
-    f04 = Column(Integer)
-    f05 = Column(Integer)
-    f06 = Column(Integer)
-    f07 = Column(Integer)
-    f08 = Column(Integer)
-    f09 = Column(Integer)
-    f10 = Column(Integer)
-    f11 = Column(Integer)
-    f12 = Column(Integer)
-    f13 = Column(Integer)
-    f14 = Column(Integer)
-    f15 = Column(Integer)
-    f16 = Column(Integer)
-    f17 = Column(Integer)
-    f18 = Column(Integer)
-    f19 = Column(Integer)
-    f20 = Column(Integer)
-    f21 = Column(Integer)
-    f22 = Column(Integer)
-    f23 = Column(Integer)
-    f24 = Column(Integer)
-    f25 = Column(Integer)
-    f26 = Column(Integer)
-    f27 = Column(Integer)
-    f28 = Column(Integer)
-    f29 = Column(Integer)
-    f30 = Column(Integer)
-    f31 = Column(Integer)
-    f32 = Column(Integer)
-    f33 = Column(Integer)
-    f34 = Column(Integer)
-    f35 = Column(Integer)
-    f36 = Column(Integer)
-    f37 = Column(Integer)
-    f38 = Column(Integer)
-    f39 = Column(Integer)
-    f40 = Column(Integer)
-    f41 = Column(Integer)
-    f42 = Column(Integer)
-    f43 = Column(Integer)
-    f44 = Column(Integer)
-    f45 = Column(Integer)
-    f46 = Column(Integer)
-    f47 = Column(Integer)
-    f48 = Column(Integer)
-    f49 = Column(Integer)
-    f50 = Column(Integer)
-    f51 = Column(Integer)
-    f52 = Column(Integer)
-    f53 = Column(Integer)
-    f54 = Column(Integer)
-    f55 = Column(Integer)
-    f56 = Column(Integer)
-    f57 = Column(Integer)
-    f58 = Column(Integer)
-    f59 = Column(Integer)
-    f60 = Column(Integer)
-    f61 = Column(Integer)
-    f62 = Column(Integer)
-    f63 = Column(Integer)
-    f64 = Column(Integer)
-    f65 = Column(Integer)
-    f66 = Column(Integer)
-    f67 = Column(Integer)
-    f68 = Column(Integer)
-    f69 = Column(Integer)
-    f70 = Column(Integer)
-    f71 = Column(Integer)
-    f72 = Column(Integer)
-    f73 = Column(Integer)
-    f74 = Column(Integer)
-    f75 = Column(Integer)
-    f76 = Column(Integer)
-    f77 = Column(Integer)
-    f78 = Column(Integer)
-    f79 = Column(Integer)
-    f80 = Column(Integer)
-    f81 = Column(Integer)
-    f82 = Column(Integer)
-    f83 = Column(Integer)
-    f84 = Column(Integer)
-    f85 = Column(Integer)
-    f86 = Column(Integer)
-    f87 = Column(Integer)
-    f88 = Column(Integer)
-    f89 = Column(Integer)
-    f90 = Column(Integer)
-    f91 = Column(Integer)
-    f92 = Column(Integer)
-    f93 = Column(Integer)
-    f94 = Column(Integer)
-    f95 = Column(Integer)
-    f96 = Column(Integer)
-    f97 = Column(Integer)
-    f98 = Column(Integer)
-    f99 = Column(Integer)
-
-    def __init__(self, issue, n1, n2, n3) -> None:
-        super().__init__()
-        self.issue = issue
-        self.num1 = n1
-        self.num2 = n2
-        self.num3 = n3
-
-    @classmethod
-    def get_follow_4049(cls):
-        session = get_session_sport()
-        data = session.query(cls).all()
-        result = {}
-        for t in data:
-            result[t.issue] = [t.f40, t.f41, t.f42, t.f43, t.f44, t.f45, t.f46, t.f47, t.f48, t.f49]
-        return result
-
-    @classmethod
-    def get_numbers(cls):
-        """
-        [[issue, num1, num2, num3],...]
-        """
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = [[x.issue, x.num1, x.num2, x.num3] for x in data]
-        return result
-
-    @classmethod
-    def get_number_and_next(cls):
-        """
-        [[issue, num1, num2, num3, next1, next2, next3],...]
-        """
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = [[x.issue, x.num1, x.num2, x.num3, x.next1, x.next2, x.next3] for x in data]
-        return result
-
-    @classmethod
-    def get_all(cls):
-        """
-        获取所有的数据
-        """
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = [[
-            x.issue,
-            x.num1,
-            x.num2,
-            x.num3,
-            x.next1,
-            x.next2,
-            x.next3,
-            x.f00,
-            x.f01,
-            x.f02,
-            x.f03,
-            x.f04,
-            x.f05,
-            x.f06,
-            x.f07,
-            x.f08,
-            x.f09,
-            x.f10,
-            x.f11,
-            x.f12,
-            x.f13,
-            x.f14,
-            x.f15,
-            x.f16,
-            x.f17,
-            x.f18,
-            x.f19,
-            x.f20,
-            x.f21,
-            x.f22,
-            x.f23,
-            x.f24,
-            x.f25,
-            x.f26,
-            x.f27,
-            x.f28,
-            x.f29,
-            x.f30,
-            x.f31,
-            x.f32,
-            x.f33,
-            x.f34,
-            x.f35,
-            x.f36,
-            x.f37,
-            x.f38,
-            x.f39,
-            x.f40,
-            x.f41,
-            x.f42,
-            x.f43,
-            x.f44,
-            x.f45,
-            x.f46,
-            x.f47,
-            x.f48,
-            x.f49,
-            x.f50,
-            x.f51,
-            x.f52,
-            x.f53,
-            x.f54,
-            x.f55,
-            x.f56,
-            x.f57,
-            x.f58,
-            x.f59,
-            x.f60,
-            x.f61,
-            x.f62,
-            x.f63,
-            x.f64,
-            x.f65,
-            x.f66,
-            x.f67,
-            x.f68,
-            x.f69,
-            x.f70,
-            x.f71,
-            x.f72,
-            x.f73,
-            x.f74,
-            x.f75,
-            x.f76,
-            x.f77,
-            x.f78,
-            x.f79,
-            x.f80,
-            x.f81,
-            x.f82,
-            x.f83,
-            x.f84,
-            x.f85,
-            x.f86,
-            x.f87,
-            x.f88,
-            x.f89,
-            x.f90,
-            x.f91,
-            x.f92,
-            x.f93,
-            x.f94,
-            x.f95,
-            x.f96,
-            x.f97,
-            x.f98,
-            x.f99
-        ] for x in data]
-        return result
-
-    @classmethod
-    def get_issues(cls):
-        """get issues"""
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = [x.issue for x in data]
-        result.sort()
-        return result
-
-
-class SportResult(Base):
-    __tablename__ = 'results'
-    issue = Column(Integer, primary_key=True)
-    num1 = Column(Integer, nullable=False)
-    num2 = Column(Integer, nullable=False)
-    num3 = Column(Integer, nullable=False)
-    next1 = Column(Integer)
-    next2 = Column(Integer)
-    next3 = Column(Integer)
-    size_position1 = Column(Integer)
-    size_position2 = Column(Integer)
-    size_position3 = Column(Integer)
-    odd_position1 = Column(Integer)
-    odd_position2 = Column(Integer)
-    odd_position3 = Column(Integer)
-    prime_position1 = Column(Integer)
-    prime_position2 = Column(Integer)
-    prime_position3 = Column(Integer)
-    sum_size = Column(Integer)
-    sum_odd = Column(Integer)
-    sum_tail_size = Column(Integer)
-    sum_tail_prime = Column(Integer)
-    span = Column(Integer)
-
-    def __init__(self, issue, n1, n2, n3):
-        self.issue = issue
-        self.num1 = n1
-        self.num2 = n2
-        self.num3 = n3
-
-    @classmethod
-    def get_column_names(cls):
-        """
-        get_column_names
-        """
-        return [
-            "issue",
-            "num1",
-            "num2",
-            "num3",
-            "next1",
-            "next2",
-            "next3",
-            "size_position1",
-            "size_position2",
-            "size_position3",
-            "odd_position1",
-            "odd_position2",
-            "odd_position3",
-            "prime_position1",
-            "prime_position2",
-            "prime_position3",
-            "sum_size",
-            "sum_odd",
-            "sum_tail_size",
-            "sum_tail_prime",
-            "span"
-        ]
-
-    @classmethod
-    def get_numbers(cls):
-        """
-        根据名称获取对应的设置项的值
-        :param name: 设置项名称
-        :return: 根据值的属性，返回对应的数据类型
-        """
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = [[x.issue, x.num1, x.num2, x.num3] for x in data]
-        return result
-
-    @classmethod
-    def get_all(cls):
-        """
-        获取所有的数据
-        """
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = [[
-            x.issue,
-            x.num1,
-            x.num2,
-            x.num3,
-            x.next1,
-            x.next2,
-            x.next3,
-            x.size_position1,
-            x.size_position2,
-            x.size_position3,
-            x.odd_position1,
-            x.odd_position2,
-            x.odd_position3,
-            x.prime_position1,
-            x.prime_position2,
-            x.prime_position3,
-            x.sum_size,
-            x.sum_odd,
-            x.sum_tail_size,
-            x.sum_tail_prime,
-            x.span
-        ] for x in data]
-        return result
-
-    @classmethod
-    def get_issues(cls):
-        """get issues"""
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = [x.issue for x in data]
-        result.sort()
-        return result
-
-
 class ExpertSummary(Base):
     """
     save_a
@@ -1228,7 +210,7 @@ class CaiYanShi(ExpertSummary):
     multi6
     multi3
     """
-    __tablename__ = 'caiyanshi'
+    __tablename__ = 'p3_caiyanshi'
     _name_ = '彩研师'
     issue = Column(Integer, primary_key=True)
 
@@ -1275,7 +257,7 @@ class CaiYanShi(ExpertSummary):
 
 
 class DaiTouDaGe(ExpertSummary):
-    __tablename__ = 'daitoudage'
+    __tablename__ = 'p3_daitoudage'
     _name_ = '带头大哥'
     issue = Column(Integer, primary_key=True)
 
@@ -1322,7 +304,7 @@ class DaiTouDaGe(ExpertSummary):
 
 
 class HuaWuQue(ExpertSummary):
-    __tablename__ = 'huawuque'
+    __tablename__ = 'p3_huawuque'
     _name_ = '花无缺'
     issue = Column(Integer, primary_key=True)
 
@@ -1360,7 +342,7 @@ class HuaWuQue(ExpertSummary):
 
 
 class QingQiuJuShi(ExpertSummary):
-    __tablename__ = 'qingqiujushi'
+    __tablename__ = 'p3_qingqiujushi'
     _name_ = '清秋居士'
     issue = Column(Integer, primary_key=True)
 
@@ -1410,7 +392,7 @@ class QingQiuJuShi(ExpertSummary):
 
 
 class ShiNaJiuWen(ExpertSummary):
-    __tablename__ = 'shinajiuwen'
+    __tablename__ = 'p3_shinajiuwen'
     _name_ = '十拿九稳'
     issue = Column(Integer, primary_key=True)
 
@@ -1454,7 +436,7 @@ class ShiNaJiuWen(ExpertSummary):
 
 
 class WanCaiLaoTou(ExpertSummary):
-    __tablename__ = 'wancailaotou'
+    __tablename__ = 'p3_wancailaotou'
     _name_ = '玩彩老头'
     issue = Column(Integer, primary_key=True)
 
@@ -1495,7 +477,7 @@ class WanCaiLaoTou(ExpertSummary):
 
 
 class XiaoYanZi(ExpertSummary):
-    __tablename__ = 'xiaoyanzi'
+    __tablename__ = 'p3_xiaoyanzi'
     _name_ = '小燕子'
     issue = Column(Integer, primary_key=True)
 
@@ -1539,7 +521,7 @@ class XiaoYanZi(ExpertSummary):
 
 
 class YueYeFeiLong(ExpertSummary):
-    __tablename__ = 'yueyefeilong'
+    __tablename__ = 'p3_yueyefeilong'
     _name_ = '月夜飞龙'
     issue = Column(Integer, primary_key=True)
 
@@ -1601,7 +583,7 @@ class ZiYunJian(ExpertSummary):
     mix5
     multi36
     """
-    __tablename__ = 'ziyunjian'
+    __tablename__ = 'p3_ziyunjian'
     _name_ = '紫云涧'
     issue = Column(Integer, primary_key=True)
 
@@ -1644,123 +626,6 @@ class ZiYunJian(ExpertSummary):
         ]
 
 
-class SportMiss(Base):
-    __tablename__ = 'misses'
-    issue = Column(Integer, primary_key=True)
-    num1 = Column(Integer, nullable=False)
-    num2 = Column(Integer, nullable=False)
-    num3 = Column(Integer, nullable=False)
-    next1 = Column(Integer)
-    next2 = Column(Integer)
-    next3 = Column(Integer)
-    miss0 = Column(Integer)
-    miss1 = Column(Integer)
-    miss2 = Column(Integer)
-    miss3 = Column(Integer)
-    miss4 = Column(Integer)
-    miss5 = Column(Integer)
-    miss6 = Column(Integer)
-    miss7 = Column(Integer)
-    miss8 = Column(Integer)
-    miss9 = Column(Integer)
-
-    def __init__(self, issue, n1, n2, n3) -> None:
-        super().__init__()
-        self.issue = issue
-        self.num1 = n1
-        self.num2 = n2
-        self.num3 = n3
-
-    def __str__(self):
-        p0 = f'i: {self.issue}\nnumbers: {self.num1}-{self.num2}-{self.num3}\n'
-        p1 = f'y  next: {self.next1}-{self.next2}-{self.next3}\n'
-        p2 = f'm i s s: {self.miss0}-{self.miss1}-{self.miss2}-{self.miss3}-'
-        p3 = f'{self.miss4}-{self.miss5}-{self.miss6}-{self.miss7}-'
-        p4 = f'{self.miss8}-{self.miss9}'
-        return p0 + p1 + p2 + p3 + p4
-
-    @classmethod
-    def get_misses(cls):
-        session = get_session_sport()
-        data = session.query(cls).all()
-        result = {}
-        for t in data:
-            result[t.issue] = [
-                t.miss0,
-                t.miss1,
-                t.miss2,
-                t.miss3,
-                t.miss4,
-                t.miss5,
-                t.miss6,
-                t.miss7,
-                t.miss8,
-                t.miss9
-            ]
-        return result
-
-    @classmethod
-    def get_numbers(cls):
-        """
-        [[issue, num1, num2, num3],...]
-        """
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = [[x.issue, x.num1, x.num2, x.num3] for x in data]
-        return result
-
-    @classmethod
-    def get_number_and_next(cls):
-        """
-        [[issue, num1, num2, num3, next1, next2, next3],...]
-        """
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = [[x.issue, x.num1, x.num2, x.num3, x.next1, x.next2, x.next3] for x in data]
-        return result
-
-    @classmethod
-    def get_all(cls):
-        """
-        获取所有的数据
-        """
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = [[
-            x.issue,
-            x.num1,
-            x.num2,
-            x.num3,
-            x.next1,
-            x.next2,
-            x.next3,
-            x.miss0,
-            x.miss1,
-            x.miss2,
-            x.miss3,
-            x.miss4,
-            x.miss5,
-            x.miss6,
-            x.miss7,
-            x.miss8,
-            x.miss9
-        ] for x in data]
-        return result
-
-    @classmethod
-    def get_issues(cls):
-        """get issues"""
-        session = get_session_sport()
-        data = session.query(cls).all()
-        session.close()
-        result = [x.issue for x in data]
-        result.sort()
-        return result
-
-
 class SportVerifyBase(Base):
     __abstract__ = True
 
@@ -1912,21 +777,8 @@ class SportVerifyBase(Base):
         return whether_train
 
 
-class SportVerify(SportVerifyBase):
-    __tablename__ = "verifies"
-
-    def __init__(self, inumabc, issue, num, abc, result, score):
-        super().__init__()
-        self.inumabc = inumabc
-        self.issue = issue
-        self.num = num
-        self.abc = abc
-        self.result = result
-        self.score = score
-
-
 class SportVerifyN(SportVerifyBase):
-    __tablename__ = "verifyn"
+    __tablename__ = "p3_verifyn"
 
     def __init__(self, inumabc, issue, num, abc, result, score):
         super().__init__()
@@ -1940,7 +792,7 @@ class SportVerifyN(SportVerifyBase):
 
 class SportNumber5(Base):
     """ numbers@p3.db """
-    __tablename__ = 'number5'
+    __tablename__ = 'number_p5'
 
     issue = Column(Integer, primary_key=True)
     num1 = Column(Integer, nullable=False)
@@ -2183,7 +1035,7 @@ class SportFollowX(Base):
 
 
 class SportFollowA(SportFollowX):
-    __tablename__ = 'followa'
+    __tablename__ = 'p5_followa'
 
     def __init__(self, issue, num) -> None:
         super().__init__()
@@ -2192,7 +1044,7 @@ class SportFollowA(SportFollowX):
 
 
 class SportFollowB(SportFollowX):
-    __tablename__ = 'followb'
+    __tablename__ = 'p5_followb'
 
     def __init__(self, issue, num) -> None:
         super().__init__()
@@ -2201,7 +1053,7 @@ class SportFollowB(SportFollowX):
 
 
 class SportFollowC(SportFollowX):
-    __tablename__ = 'followc'
+    __tablename__ = 'p5_followc'
 
     def __init__(self, issue, num) -> None:
         super().__init__()
@@ -2210,7 +1062,7 @@ class SportFollowC(SportFollowX):
 
 
 class SportFollowD(SportFollowX):
-    __tablename__ = 'followd'
+    __tablename__ = 'p5_followd'
 
     def __init__(self, issue, num) -> None:
         super().__init__()
@@ -2219,7 +1071,7 @@ class SportFollowD(SportFollowX):
 
 
 class SportFollowE(SportFollowX):
-    __tablename__ = 'followe'
+    __tablename__ = 'p5_followe'
 
     def __init__(self, issue, num) -> None:
         super().__init__()
@@ -2281,9 +1133,9 @@ class SportVerifyX(Base):
 
         # 循环模型名称
         for num in range(10):
-            for p1 in range(6):
-                for p2 in range(6):
-                    for p3 in range(6):
+            for p1 in range(10):
+                for p2 in range(10):
+                    for p3 in range(10):
                         num_a_b_c = f'{num}{p1}{p2}{p3}'
                         result[num_a_b_c] = s1
                         # 循环最后5期的数据
@@ -2418,7 +1270,7 @@ class SportVerifyX(Base):
 
 
 class SportVerifyA(SportVerifyX):
-    __tablename__ = "verifya"
+    __tablename__ = "p5_verifya"
 
     def __init__(self, inumabc) -> None:
         super().__init__()
@@ -2426,7 +1278,7 @@ class SportVerifyA(SportVerifyX):
 
 
 class SportVerifyB(SportVerifyX):
-    __tablename__ = "verifyb"
+    __tablename__ = "p5_verifyb"
 
     def __init__(self, inumabc) -> None:
         super().__init__()
@@ -2434,7 +1286,7 @@ class SportVerifyB(SportVerifyX):
 
 
 class SportVerifyC(SportVerifyX):
-    __tablename__ = "verifyc"
+    __tablename__ = "p5_verifyc"
 
     def __init__(self, inumabc) -> None:
         super().__init__()
@@ -2442,7 +1294,7 @@ class SportVerifyC(SportVerifyX):
 
 
 class SportVerifyD(SportVerifyX):
-    __tablename__ = "verifyd"
+    __tablename__ = "p5_verifyd"
 
     def __init__(self, inumabc) -> None:
         super().__init__()
@@ -2450,7 +1302,7 @@ class SportVerifyD(SportVerifyX):
 
 
 class SportVerifyE(SportVerifyX):
-    __tablename__ = "verifye"
+    __tablename__ = "p5_verifye"
 
     def __init__(self, inumabc) -> None:
         super().__init__()
@@ -2458,7 +1310,7 @@ class SportVerifyE(SportVerifyX):
 
 
 class SportFollowN(Base):
-    __tablename__ = 'follown'
+    __tablename__ = 'p3_follown'
 
     issue = Column(Integer, primary_key=True)
     num1 = Column(Integer, nullable=False)
@@ -2586,6 +1438,99 @@ class SportFollowN(Base):
         return result
 
 
+class KillSport(Base):
+    """
+    issue
+    name
+    issue_name
+    save
+    v_save
+    """
+    __tablename__ = 'p3_kill_sports'
+    issue_name = Column(String(50), primary_key=True)  # 期号_专家名
+
+    # attributes
+    issue = Column(String(50))  # 期号
+    name = Column(String(50))  # 专家名
+    save = Column(String(50))  # 组选
+
+    # verify attributes
+    v_save = Column(String(50))  # 组选成绩
+
+    @classmethod
+    def set_attributes_except_v(cls, issue_name, issue, name, save):
+        """更新数据库内容: 除了验证项目
+
+        Args:
+            issue_name(str): issue + _ + name
+            issue(str): 期号
+            name(str): name
+            save(str): save
+            path(str): 数据库保存目录
+        Returns: None
+        """
+        # create instance
+        session = cls.get_session()
+        ins = cls()
+        ins.issue_name = issue_name
+        ins.issue = issue
+        ins.name = name
+        ins.save = save
+        print(f">>> 合并数据成功, 期号_专家名: {issue_name}, save: {save}")
+        session.merge(ins)
+        session.commit()
+        session.close()
+
+    @classmethod
+    def set_attribute(cls, issue_name, attribute_name, data, path):
+        """更新数据库的某项
+
+        Args:
+            issue_name(str): issue + _ + name, 定位数据表的某条数据
+            attribute_name(str): 数据表的列
+            data(str): 保存的数据
+            path(str): 数据库保存目录
+        Returns: None
+        """
+        # 获取表的字段名称集合
+        # total_names = [str(x) for x in cls.metadata.tables[cls.__tablename__].columns]
+        # attributes = [x.replace(f'{cls.__tablename__}.', '') for x in total_names]
+        session = cls.get_session()
+        ins = cls()
+        ins.issue_name = issue_name
+        # 选择属性
+        if attribute_name == 'issue_name':
+            pass
+        elif attribute_name == 'issue':
+            ins.issue = data
+        elif attribute_name == 'name':
+            ins.name = data
+        elif attribute_name == 'save':
+            ins.save = data
+        elif attribute_name == 'v_save':
+            ins.v_save = data
+        else:
+            raise Exception(f">>> 数据表《{cls._name_}》属性名称错误!!!")
+        print(f">>> 合并数据成功: {issue_name}，{attribute_name}: {data}")
+        session.merge(ins)
+        session.commit()
+        session.close()
+
+    @classmethod
+    def get_verify(cls):
+        return cls.v_save
+
+    @staticmethod
+    def get_engine():
+        db_engine = get_engine_sport()
+        return db_engine
+
+    @staticmethod
+    def get_session():
+        session = get_session_sport()
+        return session
+
+
 if __name__ == "__main__":
     # generate tables
     # engine = create_engine("mysql+pymysql://root:Wangchenyu2012@localhost:3306/p3")
